@@ -118,7 +118,7 @@ class SyncKohaRowsCommand(BaseCommand):
                     if key != "tr_datetime":
                         record[key] = SyncKohaRowsCommand.sanitize(record[key])
                     if key == "tr_value":
-                        record[key] = int(record[key])
+                        record[key] = int(record[key]) if record[key] is not None else 0
 
         post_rows_req = requests.post(f"{Config.config['target']['url_add']}/{self.add}",
                                       json={
